#
# spec file for package libpng16
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


#
%define major   1
%define minor   6
%define micro   8
%define branch  %{major}%{minor}
%define libname libpng%{branch}-%{branch}

Name:           libpng16
Url:            http://www.libpng.org/pub/png/libpng.html
Version:        %{major}.%{minor}.%{micro}
Release:        9.5
Summary:        Library for the Portable Network Graphics Format (PNG)
License:        Zlib
Group:          System/Libraries
Source0:        ftp://ftp.simplesystems.org/pub/png/src/libpng16/libpng-%{version}.tar.xz
Source1:        ftp://ftp.simplesystems.org/pub/png/src/libpng16/Gnupg/libpng-%{version}.tar.xz.asc
Source2:        libpng16.keyring
Source3:        rpm-macros.libpng-tools
Source4:        baselibs.conf
Patch0:         libpng16-1.6.8-CVE-2014-0333.patch
Patch1:         libpng16-CVE-2014-9495.patch
Patch2:         libpng16-CVE-2015-0973.patch
Patch3:         libpng16-CVE-2015-8126.patch
Patch4:         libpng16-CVE-2015-8126-complete.patch
#BuildRequires:  gpg-offline
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  zlib-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%define debug_package_requires %{libname} = %{version}-%{release}

%package -n %{libname}

Summary:        Library for the Portable Network Graphics Format (PNG)
Group:          System/Libraries
# bug437293
%ifarch ppc64
Obsoletes:      libpng-64bit
%endif
#
Obsoletes:      libpng < %{version}
Provides:       libpng = %{version}-%{release}

%package devel
Summary:        Development Tools for applications which will use the Libpng
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Requires:       glibc-devel
Requires:       pkg-config
Requires:       zlib-devel
Recommends:     libpng%{branch}-compat-devel
# bug437293
%ifarch ppc64
Obsoletes:      libpng-devel-64bit
%endif
#

%package compat-devel
Summary:        Development Tools for applications which will use the Libpng
Group:          Development/Libraries/C and C++
Requires:       libpng%{branch}-devel = %{version}
Provides:       libpng-devel = %{version}
Obsoletes:      libpng-devel < 1.2.44
Conflicts:      otherproviders(libpng-devel)

%package tools
Summary:        Tools for Manipulating PNG Images
Group:          Productivity/Graphics/Other
Provides:       libpng-tools = %{version}
Conflicts:      otherproviders(libpng-tools)

%description
libpng is the official reference library for the Portable Network
Graphics format (PNG).

%description -n %{libname}
libpng is the official reference library for the Portable Network
Graphics format (PNG).

%description devel
The libpng%{branch}-devel package includes the header files, libraries,
configuration files and development tools necessary for compiling and
linking programs which will manipulate PNG files using libpng%{branch}.

libpng is the official reference library for the Portable Network
Graphics (PNG) format.

%description compat-devel
The libpng%{branch}-compat-devel package contains unversioned symlinks 
to the header files, libraries, configuration files and development 
tools necessary for compiling and linking programs that don't care 
about libpng version.

%description tools
Package consists of low level tools for manipulating and fixing particular
PNG files.

%prep
%setup -n libpng-%{version}
%patch0
%patch1
%patch2
%patch3
%patch4

%build
# PNG_SAFE_LIMITS_SUPPORTED: http://www.openwall.com/lists/oss-security/2015/01/10/1
export CFLAGS="%optflags -O3 -DPNG_SAFE_LIMITS_SUPPORTED -DPNG_SKIP_SETJMP_CHECK $(getconf LFS_CFLAGS)"
export LDFLAGS="-Wl,-z,relro,-z,now"

%configure \
              --disable-static \
              --with-libpng-compat=no
make %{?_smp_mflags}

%check
make check

%install
make install DESTDIR=$RPM_BUILD_ROOT 
rm $RPM_BUILD_ROOT/%{_libdir}/libpng*.la
mkdir -p %{buildroot}%{_sysconfdir}/rpm
cp -a %{SOURCE3} \
      %{buildroot}%{_sysconfdir}/rpm/macros.libpng-tools

%post -n %{libname} -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%defattr(-,root,root)
%{_libdir}/libpng%{branch}.so.*

%files devel
%defattr(-,root,root)
%{_bindir}/libpng%{branch}-config
%{_includedir}/libpng%{branch}
%{_libdir}/libpng%{branch}.so
%{_libdir}/pkgconfig/libpng%{branch}.pc
%doc CHANGES README TODO ANNOUNCE LICENSE libpng-*.txt

%files compat-devel
%defattr(-,root,root)
%{_bindir}/libpng-config
%{_includedir}/*.h
%{_libdir}/libpng.so
%{_libdir}/pkgconfig/libpng.pc
%doc %{_mandir}/man3/libpng.3.gz
%doc %{_mandir}/man3/libpngpf.3.gz
%doc %{_mandir}/man5/png.5.gz

%files tools
%defattr(-,root,root)
%{_bindir}/png-fix-itxt
%{_bindir}/pngfix
%{_sysconfdir}/rpm/macros.libpng-tools

%changelog
* Thu Dec  3 2015 pgajdos@suse.com
-  security update:
  * CVE-2015-8126 fixed incompletely [bsc#954980]
  + libpng15-CVE-2015-8126-complete.patch
* Mon Nov 16 2015 pgajdos@suse.com
- security update:
  * CVE-2015-8126 [bsc#954980]
* Thu Jan  8 2015 pgajdos@suse.com
- security update:
  * CVE-2014-9495 [bnc#912076]
    + libpng16-CVE-2014-9495.patch
  * CVE-2015-0973 [bnc#912929]
    + libpng16-CVE-2015-0973.patch
  * build with -DPNG_SAFE_LIMITS_SUPPORTED
* Tue Mar  4 2014 pgajdos@suse.com
- fixed CVE-2014-0333 [bnc#866298]
- added patches:
  * libpng16-1.6.8-CVE-2014-0333.patch
* Fri Dec 20 2013 pgajdos@suse.com
- updated to 1.6.8:
  Changed #ifdef PNG_HANDLE_AS_UNKNOWN_SUPPORTED in pngpread.c to
    [#]ifdef PNG_SET_UNKNOWN_CHUNKS_SUPPORTED to be consistent with
    what is in pngpriv.h.
  Moved prototype for png_handle_unknown() in pngpriv.h outside of
    the #ifdef PNG_SET_UNKNOWN_CHUNKS_SUPPORTED/#endif block.
  Enabled WRITE_INVERT and WRITE_PACK in contrib/pngminim/encoder.
  Fixed pngvalid 'fail' function declaration on the Intel C Compiler.
    This reverts to the previous 'static' implementation and works round
    the 'unused static function' warning by using PNG_UNUSED().
  Handle zero-length PLTE chunk or NULL palette with png_error()
    instead of png_chunk_report(), which by default issues a warning
    rather than an error, leading to later reading from a NULL pointer
    (png_ptr->palette) in png_do_expand_palette(). This is CVE-2013-6954
    and VU#650142.
* Mon Dec  2 2013 pgajdos@suse.com
- png_fix macro doesn't leave *.png.fixed (which happened for correct
  PNGs) [bnc#852862]
* Fri Nov 15 2013 pgajdos@suse.com
- updated to 1.6.7:
  * Revised unknown chunk code to correct several bugs in the
    NO_SAVE_/NO_WRITE combination
  * Check user callback behavior in pngunknown.c. Previous versions
    compiled if SAVE_UNKNOWN was not available but did nothing since the
    callback was never implemented.
  * Merged pngunknown.c with 1.7 version and back ported 1.7
    improvements/fixes
  * Revised pngvalid to generate size images with as many filters as
    it can manage, limited by the number of rows.
  * ARM improvements/fixes
* Wed Sep 25 2013 pgajdos@suse.com
- updated to 1.6.6:
  * fix arm build
* Thu Sep 12 2013 pgajdos@suse.com
- updated to 1.6.4:
  * Added information about png_set_options() to the manual.
  * Delay calling png_init_filter_functions() until a row with nonzero
    filter is found.
  * Fixed inconsistent conditional compilation of
    png_chunk_unknown_handling() prototype, definition, and usage.
    Made it depend on PNG_HANDLE_AS_UNKNOWN_SUPPORTED everywhere.
* Fri Aug 30 2013 coolo@suse.com
- remove gpg-offline usage, libpng16 is too low in the build chain
* Thu Aug  8 2013 pgajdos@suse.com
- png-fix-too-far-back was actually renamed to pngfix. Adjusted rpm
  macro names accordingly, %%png_fix and %%png_fix_dir.
* Tue Aug  6 2013 pgajdos@suse.com
- updated to 1.6.3:
  * Added png-fix-itxt and png-fix-too-far-back to the built programs and
    removed warnings from the source code and timepng that are revealed as
    a result.
  => new subpackage tools, created rpm macros
* Fri Jun 21 2013 crrodriguez@opensuse.org
- Build with LFS_CFLAGS in 32 bit archs otherwise calls such
  as png_image_begin_read_from_file() or png_image_write_to_file()
  will fail to read/write huge images.
- Build with Full RELRO as this library is a possible consumer
  of malicuous images/files.
* Fri Apr 26 2013 pgajdos@suse.com
- updated to 1.6.2:
  Updated documentation of 1.5.x to 1.6.x changes in iCCP chunk handling.
  Fixed incorrect warning of excess deflate data. End condition - the
    warning would be produced if the end of the deflate stream wasn't read
    in the last row.  The warning is harmless.
  Corrected the test on user transform changes on read. It was in the
    png_set of the transform function, but that doesn't matter unless the
    transform function changes the rowbuf size, and that is only valid if
    transform_info is called.
  Corrected a misplaced closing bracket in contrib/libtests/pngvalid.c
    (Flavio Medeiros).
  Corrected length written to uncompressed iTXt chunks (Samuli Suominen).
  Added contrib/tools/fixitxt.c, to repair the erroneous iTXt chunk length
    written by libpng-1.6.0 and 1.6.1.
  Disallow storing sRGB information when the sRGB is not supported.
  Merge pngtest.c with libpng-1.7.0
* Tue Apr  2 2013 pgajdos@suse.com
- conflict with libpng12-compat-devel-32bit and libpng15-compat-devel-32bit
* Thu Mar 28 2013 pgajdos@suse.com
- updated to 1.6.1:
  Made sRGB check numbers consistent.
  Use parentheses more consistently in "#if defined(MACRO)" tests.
  Reenabled code to allow zero length PLTE chunks for MNG.
  Fixed ALIGNED_MEMORY support.
  Avoid a possible memory leak in contrib/gregbook/readpng.c
  Better documentation of unknown handling API interactions.
  Corrected simplified API default gamma for color-mapped output, added
    a flag to change default. In 1.6.0 when the simplified API was used
    to produce color-mapped output from an input image with no gamma
    information the gamma assumed for the input could be different from
    that assumed for non-color-mapped output.  In particular 16-bit depth
    input files were assumed to be sRGB encoded, whereas in the 'direct'
    case they were assumed to have linear data.  This was an error.  The
    fix makes the simplified API treat all input files the same way and
    adds a new flag to the png_image::flags member to allow the
    application/user to specify that 16-bit files contain sRGB data
    rather than the default linear.
  etc., see ANNOUNCE or CHANGES for details
- dropped upstreamed
  0387-Reenable-code-to-allow-zero-length-PLTE-chunks-for-M.patch
* Mon Mar 18 2013 pgajdos@suse.com
- allow zero length PLTE chunks
  (fixes GraphicsMagick testsuite)
* Mon Mar  4 2013 pgajdos@suse.com
- remove clean section
* Thu Feb 14 2013 pgajdos@suse.com
- updated to 1.6.0
- changes from 1.5.x to 1.6.x:
  * new simplified api added:
    macros:
    PNG_FORMAT_*
    PNG_IMAGE_*
    structures:
    png_control
    png_image
    read functions
    png_image_begin_read_from_file()
    png_image_begin_read_from_stdio()
    png_image_begin_read_from_memory()
    png_image_finish_read()
    png_image_free()
    write functions
    png_image_write_to_file()
    png_image_write_to_stdio()
  * possibility to configure libpng to prefix all exported symbols
    (PNG_PREFIX macro)
  * no longer include string.h in png.h
  * deprecated api:
    png_info_init_3()
    png_convert_to_rfc1123() which has been replaced
    with png_convert_to_rfc1123_buffer()
    png_data_freer()
    png_malloc_default()
    png_free_default()
    png_reset_zstream()
  * removed api:
    png_get_io_chunk_name()
  * signatures of many exported functions were changed, such that
    png_structp became png_structrp or png_const_structrp
    png_infop became png_inforp or png_const_inforp
    where "rp" indicates a "restricted pointer".
- for more details see section XII of libpng-manual.txt or ANNOUNCE
* Mon Jan 14 2013 pgajdos@suse.com
- updated to 1.6.0beta37
* Tue Nov 20 2012 pgajdos@suse.com
- updated to 1.6.0beta31
* Wed Oct 24 2012 jengelh@inai.de
- Add missing baselib requires for compat-devel-32bit
* Mon Oct 15 2012 pgajdos@suse.com
- updated to 1.6.0beta29
* Wed Jul 11 2012 pgajdos@suse.com
- updated to 1.6.0beta26
* Fri Jun 15 2012 pgajdos@suse.com
- updated to 1.6.0beta24
* Thu Mar 29 2012 pgajdos@suse.com
- updated to 1.6.0beta20
* Wed Mar 14 2012 pgajdos@suse.com
- updated to 1.6.0beta17
* Mon Feb 20 2012 pgajdos@suse.com
- updated to 1.6.0beta12
* Mon Jan  9 2012 pgajdos@suse.com
- updated to 1.6.0beta04
* Mon Dec 19 2011 pgajdos@suse.com
- updated to 1.5.7:
  Added support for ARM processor (Mans Rullgard)
  Fixed bug in pngvalid on early allocation failure; fixed type cast in
    pngmem.c; pngvalid would attempt to call png_error() if the allocation
    of a png_struct or png_info failed. This would probably have led to a
    crash.  The pngmem.c implementation of png_malloc() included a cast
    to png_size_t which would fail on large allocations on 16-bit systems.
  Fix for the preprocessor of the Intel C compiler. The preprocessor
    splits adjacent @ signs with a space; this changes the concatentation
    token from @-@-@ to PNG_JOIN; that should work with all compiler
    preprocessors.
  Paeth filter speed improvements from work by Siarhei Siamashka. This
    changes the 'Paeth' reconstruction function to improve the GCC code
    generation on x86. The changes are only part of the suggested ones;
    just the changes that definitely improve speed and remain simple.
    The changes also slightly increase the clarity of the code.
  Check compression_type parameter in png_get_iCCP and remove spurious
    casts. The compression_type parameter is always assigned to, so must
    be non-NULL. The cast of the profile length potentially truncated the
    value unnecessarily on a 16-bit int system, so the cast of the (byte)
    compression type to (int) is specified by ANSI-C anyway.
  Fixed FP division by zero in pngvalid.c; the 'test_pixel' code left
    the sBIT fields in the test pixel as 0, which resulted in a floating
    point division by zero which was irrelevant but causes systems where
    FP exceptions cause a crash. Added code to pngvalid to turn on FP
    exceptions if the appropriate glibc support is there to ensure this is
    tested in the future.
  Updated scripts/pnglibconf.mak and scripts/makefile.std to handle the
    new PNG_JOIN macro.
  Added versioning to pnglibconf.h comments.
  Simplified read/write API initial version; basic read/write tested on
    a variety of images, limited documentation (in the header file.)
  Installed more accurate linear to sRGB conversion tables. The slightly
    modified tables reduce the number of 16-bit values that
    convert to an off-by-one 8-bit value.  The "makesRGB.c" code that was used
    to generate the tables is now in a contrib/sRGBtables sub-directory.
  etc. see CHANGES
* Thu Dec  1 2011 idoenmez@suse.de
- Name field shouldn't contain a macro
* Thu Dec  1 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Thu Nov  3 2011 pgajdos@suse.com
- updated to 1.5.6:
  Fixed some 64-bit type conversion warnings in pngrtran.c
  Moved row_info from png_struct to a local variable.
  The various interlace mask arrays have been made into arrays of
    bytes and made PNG_CONST and static (previously some arrays were
    marked PNG_CONST and some weren't).
  Additional checks have been added to the transform code to validate the
    pixel depths after the transforms on both read and write.
  Removed some redundant code from pngwrite.c, in png_desgtroy_write_struct().
  Changed chunk reading/writing code to use png_uint_32 instead of png_byte[4].
    This removes the need to allocate temporary strings for chunk names on
    the stack in the read/write code.  Unknown chunk handling still uses the
    string form because this is exposed in the API.
  Added a note in the manual the png_read_update_info() must be called only
    once with a particular info_ptr.
  Revised test-pngtest.sh to report FAIL when pngtest fails.
  Added "--strict" option to pngtest, to report FAIL when the failure is
    only because the resulting valid files are different.
  Revised CMakeLists.txt to work with mingw and removed some material from
    CMakeLists.txt that is no longer useful in libpng-1.5.
  Fixed typo in Makefile.in and Makefile.am ("-M Wl" should be "-M -Wl")."
  Speed up png_combine_row() for interlaced images. This reduces the generality
    of the code, allowing it to be optimized for Adam7 interlace.  The masks
    passed to png_combine_row() are now generated internally, avoiding
    some code duplication and localizing the interlace handling somewhat.
  Align png_struct::row_buf - previously it was always unaligned, caused by
    a bug in the code that attempted to align it; the code needs to subtract
    one from the pointer to take account of the filter byte prepended to
    each row.
  Optimized png_combine_row() when rows are aligned. This gains a small
    percentage for 16-bit and 32-bit pixels in the typical case where the
    output row buffers are appropriately aligned. The optimization was not
    previously possible because the png_struct buffer was always misaligned.
  Removed two redundant tests for unitialized row.
  Fixed a relatively harmless memory overwrite in compressed text writing
    with a 1 byte zlib buffer.
  Add ability to call png_read_update_info multiple times to pngvalid.c
  Fixes for multiple calls to png_read_update_info. These fixes attend to
    most of the errors revealed in pngvalid, however doing the gamma work
    twice results in inaccuracies that can't be easily fixed.  There is now
    a warning in the code if this is going to happen.
  Turned on multiple png_read_update_info in pngvalid transform tests.
  Prevent libpng from overwriting unused bits at the end of the image when
    it is not byte aligned, while reading. Prior to libpng-1.5.6 libpng would
    overwrite the partial byte at the end of each row if the row width was not
    an exact multiple of 8 bits and the image is not interlaced.
  Made png_ptr->prev_row an aligned pointer into png_ptr->big_prev_row
    (Mans Rullgard).
  Changed misleading "Missing PLTE before cHRM" warning to "Out of place cHRM"
  Added PNG_LSR() and PNG_LSL() macros to defend against buggy compilers that
    evaluate non-taken code branches and complain about out-of-range shifts.
  Renamed the local variable 'byte' because it appears in a MSYS header
    file.
  Added #define PNG_ALIGN_TYPE PNG_ALIGN_NONE to contrib/pngminim/*/pngusr.h
* Mon Sep 26 2011 pgajdos@suse.com
- updated to 1.5.5, fixes:
  * CVE-2011-3328 [bnc#720017]
* Tue Jul 26 2011 pgajdos@novell.com
- updated to 1.5.4, fixes:
  * CVE-2011-2501 [bnc#702578]
  * CVE-2011-2690 [bnc#706387]
  * CVE-2011-2691 [bnc#706388]
  * CVE-2011-2692 [bnc#706389]
* Thu Mar 31 2011 pgajdos@suse.cz
- updated to 1.5.2:
  * Turned on interlace handling in png_read_png().
  * Fixed gcc pendantic warnings.
  * Fixed png_get_current_row_number() in the interlaced case.
  * Cleaned up ALPHA flags and transformations.
  * Implemented expansion to 16 bits.
  * etc, see
    http://sourceforge.net/projects/libpng/files/libpng15/1.5.2/
* Thu Feb  3 2011 pgajdos@suse.cz
- updated to 1.5.1: new branch shortly after 1.4, many structural
  changes, see CHANGELOG or
  http://sourceforge.net/projects/libpng/files/libpng15/1.5.0/
  and
  http://sourceforge.net/projects/libpng/files/libpng15/1.5.1/
* Thu Sep 30 2010 pgajdos@novell.com
- updated to 1.4.4:
  * Eliminated another deprecated reference to png_ptr->io_ptr in pngtest.c
  * Updated the xcode project to work with libpng-1.4.x and added iOS targets
    for simulator and device (Philippe Hausler).
  * Eliminated a deprecated reference to png_ptr->io_ptr in pngtest.c
  * Removed unused png_mem_* defines from pngconf.h.
  * Updated the read macros and functions from 1.5.0beta38.
* Mon Aug 30 2010 coolo@novell.com
- fix baselibs.conf after previous change
* Thu Jul 29 2010 pgajdos@suse.cz
- add devel packages to baselbis.conf [bnc#625883]
* Mon Jun 28 2010 pgajdos@suse.cz
- updated to 1.4.3: fixed libpng overflow (CVE-2010-1205)
  and memory leak [bnc#617866]
* Fri Jun  4 2010 coolo@novell.com
- remove devel packages from baselibs.conf, not convinced of
  their usefulness
* Mon May  3 2010 dmueller@suse.de
- also obsolete libpng-devel-1.2.43 (previous factory version)
* Sat Apr 24 2010 coolo@novell.com
- buildrequire pkg-config to fix provides
* Thu Apr 15 2010 pgajdos@suse.cz
- support png_read_dither() for xfig and transfig
  * read-dither.patch
* Tue Apr  6 2010 ro@suse.de
- fix baselibs.conf
* Thu Mar 25 2010 pgajdos@suse.cz
- updated to 1.4.1 -- new branch
* Thu Feb 25 2010 pgajdos@suse.cz
- updated to 1.2.43 (fixes [bnc#585403]):
  * Removed "#define PNG_NO_ERROR_NUMBERS" that was inadvertently added
    to pngconf.h in version 1.2.41.
  * Removed leftover "-DPNG_CONFIGURE_LIBPNG" from scripts/makefile.darwin
    and contrib/pngminim/*/makefile
  * Relocated png_do_chop() to its original position in pngrtran.c; the
    change in version 1.2.41beta08 caused transparency to be handled wrong
    in some 16-bit datastreams (Yusaku Sugai).
  * Renamed libpng-pc.in back to libpng.pc.in and revised CMakeLists.txt
    (revising changes made in 1.2.41)
  * Swapped PNG_UNKNOWN_CHUNKS_SUPPORTED and PNG_HANDLE_AS_UNKNOWN_SUPPORTED
    in pngset.c to be consistent with other changes in version 1.2.38.
  * Avoid deprecated references to png_ptr-io_ptr and png_ptr->error_ptr
    in pngtest.c
* Mon Dec 14 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Mon Dec  7 2009 pgajdos@suse.cz
- updated to 1.2.41:
  contains numerous cleanups, some new compile-time warnings about
  direct struct access (define PNG_NO_PEDANTIC_WARNINGS to enable),
  a new xcode build project, and a minor performance improvement
  (avoid building 16-bit gamma tables when not needed)
* Tue Nov 24 2009 pgajdos@suse.cz
- updated to 1.2.40:
  Removed an extra png_debug() recently added to png_write_find_filter().
  Fixed incorrect #ifdef in pngset.c regarding unknown chunk support.
  Various bugfixes and improvements to CMakeLists.txt (Philip Lowman)
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Thu Aug 13 2009 pgajdos@suse.cz
- updated to 1.2.39:
  * Added a prototype for png_64bit_product() in png.c
  * Avoid a possible NULL dereference in debug build,
    in png_set_text_2()
  * Relocated new png_64_bit_product() prototype into png.h
  * Replaced *.tar.lzma with *.txz in distribution.
  * Reject attempt to write iCCP chunk with negative embedded
    profile length.
* Mon Jul 20 2009 pgajdos@suse.cz
- updated to 1.2.38:
  * Revised libpng*.txt and libpng.3 to mention calling png_set_IHDR()
    multiple times and to specify the sample order in the tRNS chunk,
    because the ISO PNG specification has a typo in the tRNS table.
  * Changed several PNG_UNKNOWN_CHUNK_SUPPORTED to
    PNG_HANDLE_AS_UNKNOWN_SUPPORTED, to make the png_set_keep mechanism
    available for ignoring known chunks even when not saving unknown chunks.
  * Adopted preference for consistent use of "#ifdef" and "#ifndef" versus
    "#if defined()" and "if !defined()" where possible.
  * Added PNG_NO_HANDLE_AS_UNKNOWN in the PNG_LEGACY_SUPPORTED block of
    pngconf.h, and moved the various unknown chunk macro definitions
    outside of the PNG_READ|WRITE_ANCILLARY_CHUNK_SUPPORTED blocks.
* Thu Jun  4 2009 pgajdos@suse.cz
- updated to 1.2.37:
  * fixed bug with new png_memset() of the big_row_buffer
* Tue May 12 2009 pgajdos@suse.cz
- updated to 1.2.36 (see CHANGES)
* Mon Feb 23 2009 pgajdos@suse.cz
- fixes possible double free [bnc#472745]
  (CVE-2009-0040)
* Mon Jan 19 2009 pgajdos@suse.cz
- updated to 1.2.34:
  * fixes CVE-2008-3964 (removed CVE-2008-3964.patch)
* Tue Jan 13 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Mon Sep 15 2008 pgajdos@suse.cz
- fixed CVE-2008-3964 [bnc#424739]
  * CVE-2008-3964.patch
* Thu Sep 11 2008 pgajdos@suse.cz
- updated to version 1.2.31:
  * coding bugfixes and enhancements
* Mon Sep  1 2008 aj@suse.de
- Do not package la files.
* Mon Jun 23 2008 pgajdos@suse.cz
- updated to 1.2.29:
  * fixes to the configure-related build-scripts
  * security fix that affects programs that attempt to do
    special handling of unknown PNG chunks (presumably very
    few such programs), along with a reversion to previous
    behavior for handling of images with out-of-range tRNS-chunk
    values [bnc#378634]
  * fix for unintentional gray-to-RGB conversion in
    png_set_expand_gray_1_2_4_to_8()
  * various other minor fixes
- removed makefile-am.patch, issue fixed upstream
* Sun May 11 2008 coolo@suse.de
- fix rename of xxbit packages
* Tue Apr 22 2008 pgajdos@suse.cz
- $(ECHO) substituted by echo in Makefile.in -- fixes package
  build in beta (makefile-am.patch)
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Thu Apr  3 2008 pgajdos@suse.cz
- updated to 1.2.26:
  * fixed minor coding errors that could lead to crashes in
    exceptional cases
* Thu Dec  6 2007 mrueckert@suse.de
- added provides/obsoletes for the old package
* Fri Nov 30 2007 nadvornik@suse.cz
- updated to 1.2.23:
  * more sanity checks, fixes [#332249]
- adjusted to Shared Library Policy:
  * renamed package libpng to libpng12-0
  * created compatibility package libpng3
* Wed Jul 11 2007 nadvornik@suse.cz
- updated to 1.2.18:
  * security fixes merged upstream
* Thu Mar 29 2007 aj@suse.de
- Add zlib-devel to BuildRequires.
* Thu Nov 23 2006 nadvornik@suse.cz
- fixed crash on malformed sPLT chunks CVE-2006-5793 [#219007]
* Mon Jul 17 2006 nadvornik@suse.cz
- make sure PNG_NO_ASSEMBLER_CODE is used consistently
* Thu Jun 29 2006 nadvornik@suse.cz
- updated to 1.2.12:
  * fixed possible buffer overflow [#189241]
* Wed Jun 21 2006 nadvornik@suse.cz
- updated to 1.2.10:
  * use autoconf
  * many bugfixes
- libpng12-config no longer gives -Wl,-rpath,/usr/lib [#168627]
- spec file cleanup
* Fri Feb 24 2006 nadvornik@suse.cz
- removed libpng-64bit.diff [#153106]
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 12 2006 nadvornik@suse.cz
- compile with -fstack-protector
* Mon Oct 10 2005 nadvornik@suse.cz
- fixed incorrect inline asm usage
* Thu May 19 2005 ro@suse.de
- fix libdir in pkgconfig file libpng.pc
* Thu Jan 20 2005 nadvornik@suse.cz
- updated to 1.2.8:
  * fixed crash of applications that strip the alpha channel
  * fixed invalid zlib header within the PNG datastream
* Mon Sep 27 2004 sf@suse.de
-  fixed problem with wrong assumption for long on 64bit archs
  which prevents khunphan from working (#45738)
* Wed Aug 25 2004 kukuk@suse.de
- Avoid /bin/sh PreRequires
* Mon Aug 16 2004 nadvornik@suse.cz
- updated to 1.2.6: included security fixes
* Mon Jul 19 2004 nadvornik@suse.cz
- fixed several buffer overflows [#43008]
* Wed Jun 16 2004 nadvornik@suse.cz
- added missing part of pngtran overflow patch [#42043]
* Fri Apr 23 2004 nadvornik@suse.cz
- fixed reading behind end of string [#39180]
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Fri Oct 10 2003 adrian@suse.de
- add %%run_ldconfig
* Mon Apr  7 2003 ro@suse.de
- fix tail calling syntax
* Mon Feb 10 2003 nadvornik@suse.cz
- link the shared library with -lz -lm -lc again
* Wed Jan 29 2003 kukuk@suse.de
- Fix libpng-devel requires (add zlib-devel) [Bug #23154]
* Fri Jan 24 2003 sbrabec@suse.cz
- Added missing pkgconfig files to %%files.
* Tue Jan  7 2003 nadvornik@suse.cz
- updated to 1.2.5
- fixed buffer overflow
* Wed Jul 31 2002 coolo@suse.de
- fix libz dependency, so the resulting libpng is self containing
* Fri Jul 26 2002 adrian@suse.de
- fix neededforbuild
* Wed Jul 24 2002 nadvornik@suse.cz
- updated to 1.2.4:
  - fixed buffer overflow in pngpread.c when IDAT is
    corrupted with extra data
* Fri Jul 12 2002 schwab@suse.de
- Fix makefile.
* Fri Jul  5 2002 kukuk@suse.de
- Use %%ix86 macro
* Tue Jul  2 2002 nadvornik@suse.cz
- updated to 1.2.3
- changed package version to match the version of source tarball
* Tue Mar  5 2002 nadvornik@suse.cz
- fixed permissions for man pages
* Tue Feb  5 2002 nadvornik@suse.cz
- added Provides: libpng:/usr/include/png.h to libpng-devel
* Thu Jan 31 2002 nadvornik@suse.cz
- back to 1.0.12, libpng 1.2.x will be packed in separate package
- created devel subpackage to allow parallel instalation of
  shared libraries
* Wed Jan  9 2002 nadvornik@suse.cz
- update to 1.2.1
- used macros %%{_lib} and %%{_libdir}
* Tue Dec  4 2001 nadvornik@suse.cz
- update to 1.2.0
  - shared library version changed to 3.1.2.0
  - new API for dynamically enabling and disabling certain optimizations
- added Provides: libpng-devel for compatibility [bug #11978]
* Tue Jul 17 2001 nadvornik@suse.cz
- update to 1.0.12
* Tue Apr  3 2001 nadvornik@suse.cz
- update to 1.0.10
- used pnggccrd.c - MMX support on intel
* Tue Feb 13 2001 nadvornik@suse.cz
- update to 1.0.9
* Fri Jan 19 2001 bk@suse.de
- call pngtest program to have some tests that libpng works.
- don't remove -O3 when adding RPM_OPT_FLAGS(still do -O3 optimisations)
* Thu Jan  4 2001 nadvornik@suse.cz
- changed rpm version to 2.1.0.8 (bug #5062)
- changed shared library name to libpng.so.2.1.0.8
* Wed Aug 23 2000 nadvornik@suse.cz
- update to 1.0.8
* Tue Jul 11 2000 adrian@suse.de
- seg fault fix in pngrutil.c
* Mon May 22 2000 nadvornik@suse.cz
- changed group
- changed URL
* Sat Apr 29 2000 kukuk@suse.de
- Make sure libpng.so.2 is linked against libz to avoid problems
  with missing dependencies.
* Mon Apr 10 2000 nadvornik@suse.cz
- added URL
* Tue Apr  4 2000 nadvornik@suse.cz
- update to 1.0.6
- added BuildRoot
* Tue Jan 25 2000 ro@suse.de
- update to 1.0.5
- manpages to /usr/share using macro
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Tue Jun 29 1999 ro@suse.de
- moved from /usr/X11R6 to /usr
* Mon Jun 28 1999 ro@suse.de
- update to 1.0.3
* Wed Feb 17 1999 ro@suse.de
- added .so.2 link
* Fri Jan 22 1999 ro@suse.de
- bump version to 2.1.0 (the version of the installed library)
* Fri Mar 20 1998 ro@suse.de
- extracted package from libgr tree
  update to version 1.0.1
